<?php

/*

Author: Eddie Machado

URL: htp://themble.com/bones/



This is where you can drop your custom functions or

just edit things like thumbnail sizes, header images, 

sidebars, comments, ect.

*/



// Get Bones Core Up & Running!

require_once('library/bones.php');            // core functions (don't remove)

// require_once('library/custom-post-type.php'); // custom post type example



// Admin Functions (commented out by default)

// require_once('library/admin.php');         // custom admin functions


if ( ! isset( $content_width ) ) 
    $content_width = 780;



/************* THUMBNAIL SIZE OPTIONS *************/



// Thumbnail sizes

add_image_size( 'bones-thumb-600', 600, 150, true );

add_image_size( 'bones-thumb-300', 300, 100, true );

/* 

to add more sizes, simply copy a line from above 

and change the dimensions & name. As long as you

upload a "featured image" as large as the biggest

set width or height, all the other sizes will be

auto-cropped.



To call a different size, simply change the text

inside the thumbnail function.



For example, to call the 300 x 300 sized image, 

we would use the function:

<?php the_post_thumbnail( 'bones-thumb-300' ); ?>

for the 600 x 100 image:

<?php the_post_thumbnail( 'bones-thumb-600' ); ?>



You can change the names and dimensions to whatever

you like. Enjoy!

*/



/************* ACTIVE SIDEBARS ********************/



// Sidebars & Widgetizes Areas

function bones_register_sidebars() {

    register_sidebar(array(

    	'id' => 'left',

    	'name' => 'Left sidebar',

    	'description' => 'Left part of the footer.',

    	'before_widget' => '<div id="%1$s" class="widget %2$s">',

    	'after_widget' => '</div>',

    	'before_title' => '<h4 class="widgettitle">',

    	'after_title' => '</h4>',

    ));



    register_sidebar(array(

    	'id' => 'center',

    	'name' => 'Center sidebar',

    	'description' => 'Center part of the footer.',

    	'before_widget' => '<div id="%1$s" class="widget %2$s">',

    	'after_widget' => '</div>',

    	'before_title' => '<h4 class="widgettitle">',

    	'after_title' => '</h4>',

    ));



    register_sidebar(array(

    	'id' => 'right',

    	'name' => 'Right sidebar',

    	'description' => 'Right part of the footer.',

    	'before_widget' => '<div id="%1$s" class="widget %2$s">',

    	'after_widget' => '</div>',

    	'before_title' => '<h4 class="widgettitle">',

    	'after_title' => '</h4>',

    ));

    

    /* 

    to add more sidebars or widgetized areas, just copy

    and edit the above sidebar code. In order to call 

    your new sidebar just use the following code:

    

    Just change the name to whatever your new

    sidebar's id is, for example:

    

    register_sidebar(array(

    	'id' => 'sidebar2',

    	'name' => 'Sidebar 2',

    	'description' => 'The second (secondary) sidebar.',

    	'before_widget' => '<div id="%1$s" class="widget %2$s">',

    	'after_widget' => '</div>',

    	'before_title' => '<h4 class="widgettitle">',

    	'after_title' => '</h4>',

    ));

    

    To call the sidebar in your template, you can just copy

    the sidebar.php file and rename it to your sidebar's name.

    So using the above example, it would be:

    sidebar-sidebar2.php

    

    */

} // don't remove this bracket!



/************* COMMENT LAYOUT *********************/

		

// Comment Layout

function bones_comments($comment, $args, $depth) {

   $GLOBALS['comment'] = $comment; ?>

	<li <?php comment_class(); ?>>

		<article id="comment-<?php comment_ID(); ?>" class="clearfix">

			<header class="comment-author vcard">

				<?php echo get_avatar($comment,$size='32',$default='<path_to_url>' ); ?>

				<?php printf(__('<cite class="fn">%s</cite>'), get_comment_author_link()) ?>

				<time datetime="<?php echo comment_time('Y-m-j'); ?>"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php comment_time('F jS, Y'); ?> </a></time>

				<?php edit_comment_link(__('(Edit)'),'ahab') ?>

			</header>

			<?php if ($comment->comment_approved == '0') : ?>

       			<div class="help">

          			<p><?php _e('Your comment is awaiting moderation.','ahab') ?></p>

          		</div>

			<?php endif; ?>

			<section class="comment_content clearfix">

				<?php comment_text() ?>

			</section>

			<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>

		</article>

    <!-- </li> is added by wordpress automatically -->

<?php

} // don't remove this bracket!



/************* SEARCH FORM LAYOUT *****************/



// Search Form

function bones_wpsearch($form) {

    $form = '<form role="search" method="get" id="searchform" action="' . home_url( '/' ) . '" >

    <label class="screen-reader-text" for="s">' . __('Search for:', 'bonestheme') . '</label>

    <input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="Search the Site..." />

    <input type="submit" id="searchsubmit" value="'. esc_attr__('Search') .'" />

    </form>';

    return $form;

} // don't remove this bracket!



/******* CUSTOM DINAMIC EXCERPT ********/



// Variable & intelligent excerpt length.

function print_excerpt($length) { // Max excerpt length. Length is set in characters

	global $post;

	$text = $post->post_excerpt;

	if ( '' == $text ) {

		$text = get_the_content('');

		$text = apply_filters('the_content', $text);

		$text = str_replace(']]>', ']]>', $text);

	}

	$text = strip_shortcodes($text); // optional, recommended

	$text = strip_tags($text); // use ' $text = strip_tags($text,'<p><a>'); ' if you want to keep some tags



	$text = substr($text,0,$length);

	$excerpt = reverse_strrchr($text, '.', 1);

	if( $excerpt ) {

		echo apply_filters('the_excerpt',$excerpt);

	} else {

		echo apply_filters('the_excerpt',$text);

	}

}



// Returns the portion of haystack which goes until the last occurrence of needle

function reverse_strrchr($haystack, $needle, $trail) {

    return strrpos($haystack, $needle) ? substr($haystack, 0, strrpos($haystack, $needle) + $trail) : false;

}



?>